import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';
import * as i2 from '@angular/material/tabs';
import { MatTabsModule } from '@angular/material/tabs';
import * as i3 from '@angular/material/grid-list';
import { MatGridListModule } from '@angular/material/grid-list';
import * as i4 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i5 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i2$1 from '@angular/common';
import { CommonModule, DatePipe } from '@angular/common';
import * as i11 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i5$1 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import { RouterModule } from '@angular/router';
import { BrowserModule } from '@angular/platform-browser';
import * as i6 from '@angular/material/datepicker';
import { MatDatepickerModule } from '@angular/material/datepicker';
import * as i7 from '@angular/material/select';
import { MatSelectModule } from '@angular/material/select';
import * as i8 from '@angular/material/core';
import { MatOptionModule } from '@angular/material/core';
import * as i10 from '@angular/forms';
import { FormsModule } from '@angular/forms';

class ReportsService {
    constructor(httpClient) {
        this.httpClient = httpClient;
    }
    loadGroups(url) {
        return this.httpClient.get(url);
    }
    listReportsByGroupId(url, groupId) {
        return this.httpClient.get(`${url}/${groupId}`);
    }
    getReportWithFilters(url, reportId) {
        // return this.httpClient.get(`/rpt/report/${reportId}`);
        return this.httpClient.get(`${url}/${reportId}`);
    }
}
ReportsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
ReportsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }]; } });

let breakpoint;
function sharedGridLayout(resize, event) {
    let size;
    if (resize) {
        size = event.target.innerWidth;
        //console.log('event',size)
    }
    else {
        size = window.innerWidth;
    }
    switchMethod(size);
    return breakpoint;
}
function switchMethod(size) {
    switch (true) {
        case (size <= 768):
            breakpoint = 1;
            break;
        case (size >= 768 && size <= 992):
            breakpoint = 2;
            break;
        case (size >= 992):
            breakpoint = 3;
            break;
    }
}

class ReportsComponent {
    constructor(reportService) {
        this.reportService = reportService;
        this.reportsGroups = [];
        this.reportsByGroupId = [];
        this.$subs = [];
        this.onViewClicked = new EventEmitter();
        this.breakpoint = 2;
    }
    ngOnInit() {
        this.loadGroups();
    }
    loadGroups() {
        const sub1 = this.reportService.loadGroups(this.urlReportGroups).subscribe(res => {
            this.reportsGroups = res;
            this.$subs.push(sub1);
        });
    }
    listReportsByGroupId(groupId) {
        const sub2 = this.reportService.listReportsByGroupId(this.reportGroupByIdUrl, groupId).subscribe(res2 => {
            this.reportsByGroupId = res2;
        });
        this.$subs.push(sub2);
    }
    ;
    onTabChanged(event) {
        this.listReportsByGroupId(this.reportsGroups[event].id);
    }
    viewReportFilterDetails(report) {
        this.onViewClicked.emit(report);
    }
    onResize(event) {
        this.breakpoint = sharedGridLayout(true, event);
        console.log('breakPoint', this.breakpoint);
    }
    ngOnDestroy() {
        this.$subs.forEach((item) => item.unsubscribe());
    }
}
ReportsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsComponent, deps: [{ token: ReportsService }], target: i0.ɵɵFactoryTarget.Component });
ReportsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: ReportsComponent, selector: "lib-reports-groups", inputs: { urlReportGroups: "urlReportGroups", reportGroupByIdUrl: "reportGroupByIdUrl" }, outputs: { onViewClicked: "onViewClicked" }, ngImport: i0, template: `

    <mat-tab-group *ngIf="reportsGroups" (selectedIndexChange)="onTabChanged($event)">
      <mat-tab [id]="group.id" *ngFor="let group of reportsGroups;let i=index" label="{{group.name}}">
        <mat-grid-list class="mt-2" [cols]="breakpoint" (window:resize)="onResize($event)" rowHeight="200px">
          <mat-grid-tile *ngFor="let report of reportsByGroupId">
            <mat-card class="example-card">
              <mat-card-title>{{report.name}}</mat-card-title>
              <mat-card-content>
                <p>{{report.descreption}}</p>
              </mat-card-content>
              <mat-card-actions>
                <button mat-button class="viewButton" (click)="viewReportFilterDetails(report)">View</button>
              </mat-card-actions>
            </mat-card>
          </mat-grid-tile>
        </mat-grid-list>

      </mat-tab>
    </mat-tab-group>
  `, isInline: true, styles: ["\n    .example-card {\n      max-width: 350px;\n      border-radius: 8px;\n      height: 100%;\n      overflow: auto;\n      width: 93%\n    }\n\n    .viewButton {\n      background: #FF6600\n    }\n  "], components: [{ type: i2.MatTabGroup, selector: "mat-tab-group", inputs: ["color", "disableRipple"], exportAs: ["matTabGroup"] }, { type: i2.MatTab, selector: "mat-tab", inputs: ["disabled", "label", "aria-label", "aria-labelledby"], exportAs: ["matTab"] }, { type: i3.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: i4.MatCard, selector: "mat-card", exportAs: ["matCard"] }, { type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.MatCardTitle, selector: "mat-card-title, [mat-card-title], [matCardTitle]" }, { type: i4.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }, { type: i4.MatCardActions, selector: "mat-card-actions", inputs: ["align"], exportAs: ["matCardActions"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'lib-reports-groups',
                    template: `

    <mat-tab-group *ngIf="reportsGroups" (selectedIndexChange)="onTabChanged($event)">
      <mat-tab [id]="group.id" *ngFor="let group of reportsGroups;let i=index" label="{{group.name}}">
        <mat-grid-list class="mt-2" [cols]="breakpoint" (window:resize)="onResize($event)" rowHeight="200px">
          <mat-grid-tile *ngFor="let report of reportsByGroupId">
            <mat-card class="example-card">
              <mat-card-title>{{report.name}}</mat-card-title>
              <mat-card-content>
                <p>{{report.descreption}}</p>
              </mat-card-content>
              <mat-card-actions>
                <button mat-button class="viewButton" (click)="viewReportFilterDetails(report)">View</button>
              </mat-card-actions>
            </mat-card>
          </mat-grid-tile>
        </mat-grid-list>

      </mat-tab>
    </mat-tab-group>
  `,
                    styles: [`
    .example-card {
      max-width: 350px;
      border-radius: 8px;
      height: 100%;
      overflow: auto;
      width: 93%
    }

    .viewButton {
      background: #FF6600
    }
  `]
                }]
        }], ctorParameters: function () { return [{ type: ReportsService }]; }, propDecorators: { urlReportGroups: [{
                type: Input
            }], reportGroupByIdUrl: [{
                type: Input
            }], onViewClicked: [{
                type: Output
            }] } });

class ReportDetailsComponent {
    constructor(reportService, datepipe) {
        this.reportService = reportService;
        this.datepipe = datepipe;
        this.$subs = [];
        this.breakpoint = 2;
        this.onExecuteFired = new EventEmitter();
    }
    ngOnInit() {
        this.breakpoint = sharedGridLayout();
        this.loadReportFilters();
    }
    onResize(event) {
        this.breakpoint = sharedGridLayout(true, event);
    }
    loadReportFilters() {
        const sub1 = this.reportService.getReportWithFilters(this.loadReportDetailFilters, this.reportId).subscribe(res => {
            this.reportDetails = res;
        });
        this.$subs.push(sub1);
    }
    ngOnDestroy() {
        this.$subs.forEach((item) => item.unsubscribe());
    }
    validateAndConvertData() {
        var _a, _b;
        if (this.reportDetails && this.reportDetails.reportFilters) {
            for (let i = 0; i < ((_b = (_a = this.reportDetails) === null || _a === void 0 ? void 0 : _a.reportFilters) === null || _b === void 0 ? void 0 : _b.length); i++) {
                this.reportDetails.reportFilters[i].value
                    = this.reportDetails.reportFilters[i].dataType.toLocaleLowerCase() === 'date'
                        ? this.datepipe.transform(this.reportDetails.reportFilters[i].value, 'yyyy-MM-dd')
                        : this.reportDetails.reportFilters[i].value;
            }
        }
        return true;
    }
    execute() {
        var _a;
        if ((_a = this.executeForm) === null || _a === void 0 ? void 0 : _a.invalid) {
            this.executeForm.form.markAllAsTouched();
            return;
        }
        this.validateAndConvertData();
        sessionStorage.setItem('executeForm', JSON.stringify(this.reportDetails.reportFilters));
        sessionStorage.setItem('reportName', this.reportDetails.name);
    }
}
ReportDetailsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportDetailsComponent, deps: [{ token: ReportsService }, { token: i2$1.DatePipe }], target: i0.ɵɵFactoryTarget.Component });
ReportDetailsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: ReportDetailsComponent, selector: "lib-report-details", inputs: { reportId: "reportId", loadReportDetailFilters: "loadReportDetailFilters" }, outputs: { onExecuteFired: "onExecuteFired" }, viewQueries: [{ propertyName: "executeForm", first: true, predicate: ["f"], descendants: true }], ngImport: i0, template: "<mat-card class=\"example-card\">\n  <mat-card-title>{{reportDetails?.name}}</mat-card-title>\n  <mat-card-subtitle>{{reportDetails?.descreption}}</mat-card-subtitle>\n  <mat-card-content *ngIf=\"reportDetails\">\n    <form name=\"form\"  #f=\"ngForm\" novalidate >\n      <mat-grid-list class=\"mt-2\" [cols]=\"breakpoint\" (window:resize)=\"onResize($event)\" rowHeight=\"100px\">\n        <mat-grid-tile *ngFor=\"let filter of reportDetails.reportFilters\">\n          <mat-form-field class=\"form-field\" appearance=\"outline\" *ngIf=\"filter.dataType.toLowerCase() == 'date' \">\n            <mat-label class=\"form-label\">{{filter.name}} </mat-label>\n            <input matInput [matDatepicker]=\"picker\" #date=\"ngModel\"\n                   [name]=\"filter.name\" [(ngModel)]=\"filter.value\" [required]=\"filter.required\">\n            <mat-datepicker-toggle matSuffix [for]=\"picker\"></mat-datepicker-toggle>\n            <mat-datepicker #picker></mat-datepicker>\n\n          </mat-form-field>\n\n          <mat-form-field class=\"form-field\" appearance=\"outline\" *ngIf=\"filter.dataType.toLowerCase() == 'text' \">\n            <mat-label class=\"form-label\">{{filter.name}} </mat-label>\n            <input matInput *ngIf=\"filter.dataType.toLowerCase() == 'text' \" [name]=\"filter.name\"\n                   [(ngModel)]=\"filter.value\" [required]=\"filter.required\">\n          </mat-form-field>\n          <mat-form-field class=\"form-field\" appearance=\"outline\" *ngIf=\"filter.dataType.toLowerCase() == 'number' \">\n            <mat-label class=\"form-label\">{{filter.name}} </mat-label>\n            <input matInput type=\"number\" [name]=\"filter.name\"\n                   [(ngModel)]=\"filter.value\" [required]=\"filter.required\" >\n          </mat-form-field>\n\n          <mat-form-field class=\"form-field\" appearance=\"outline\"\n                          *ngIf=\"filter.dataType.toLowerCase() == 'query' || filter.dataType.toLowerCase() ==='lookup'\">\n            <mat-label class=\"form-label\">{{filter.name}} </mat-label>\n            <mat-select *ngIf=\"filter.dataType.toLowerCase() == 'query' || filter.dataType.toLowerCase() ==='lookup'\"\n                        [name]=\"filter.name\" [(ngModel)]=\"filter.value\" [required]=\"filter.required\">\n              <mat-option *ngFor=\"let option of filter.lookUps\" [value]=\"option.id\">{{option.name}}</mat-option>\n            </mat-select>\n          </mat-form-field>\n        </mat-grid-tile>\n      </mat-grid-list>\n    </form>\n    <button  type=\"submit\" mat-button class=\"viewButton\" (click)=\"execute()\">Execute</button>\n\n  </mat-card-content>\n</mat-card>\n", styles: [".example-card{height:100%;width:100%;border-radius:8px}.mat-form-field{width:93%}.viewButton{background:#FF6600}.mat-grid-tile-content{display:block!important}.mat-drawer-content{overflow:hidden!important}\n"], components: [{ type: i4.MatCard, selector: "mat-card", exportAs: ["matCard"] }, { type: i3.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: i5$1.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i6.MatDatepickerToggle, selector: "mat-datepicker-toggle", inputs: ["tabIndex", "disabled", "for", "aria-label", "disableRipple"], exportAs: ["matDatepickerToggle"] }, { type: i6.MatDatepicker, selector: "mat-datepicker", exportAs: ["matDatepicker"] }, { type: i7.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i8.MatOption, selector: "mat-option", exportAs: ["matOption"] }, { type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i4.MatCardTitle, selector: "mat-card-title, [mat-card-title], [matCardTitle]" }, { type: i4.MatCardSubtitle, selector: "mat-card-subtitle, [mat-card-subtitle], [matCardSubtitle]" }, { type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i4.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }, { type: i10.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i10.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i10.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5$1.MatLabel, selector: "mat-label" }, { type: i11.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i6.MatDatepickerInput, selector: "input[matDatepicker]", inputs: ["matDatepicker", "min", "max", "matDatepickerFilter"], exportAs: ["matDatepickerInput"] }, { type: i10.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i10.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i10.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i10.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { type: i5$1.MatSuffix, selector: "[matSuffix]" }, { type: i10.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportDetailsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'lib-report-details',
                    templateUrl: './report-details.component.html',
                    styleUrls: ['./report-details.component.css']
                }]
        }], ctorParameters: function () { return [{ type: ReportsService }, { type: i2$1.DatePipe }]; }, propDecorators: { reportId: [{
                type: Input
            }], executeForm: [{
                type: ViewChild,
                args: ['f']
            }], loadReportDetailFilters: [{
                type: Input
            }], onExecuteFired: [{
                type: Output
            }] } });

class ReportsModule {
}
ReportsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ReportsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, declarations: [ReportsComponent,
        ReportDetailsComponent], imports: [CommonModule,
        BrowserModule,
        MatInputModule,
        MatFormFieldModule,
        MatTabsModule,
        MatGridListModule,
        MatCardModule,
        MatButtonModule,
        HttpClientModule,
        RouterModule,
        MatDatepickerModule,
        FormsModule,
        MatSelectModule,
        MatOptionModule], exports: [ReportsComponent,
        ReportDetailsComponent] });
ReportsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, providers: [DatePipe], imports: [[
            CommonModule,
            BrowserModule,
            MatInputModule,
            MatFormFieldModule,
            MatTabsModule,
            MatGridListModule,
            MatCardModule,
            MatButtonModule,
            HttpClientModule,
            RouterModule,
            MatDatepickerModule,
            FormsModule,
            MatSelectModule,
            MatOptionModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ReportsComponent,
                        ReportDetailsComponent
                    ],
                    imports: [
                        CommonModule,
                        BrowserModule,
                        MatInputModule,
                        MatFormFieldModule,
                        MatTabsModule,
                        MatGridListModule,
                        MatCardModule,
                        MatButtonModule,
                        HttpClientModule,
                        RouterModule,
                        MatDatepickerModule,
                        FormsModule,
                        MatSelectModule,
                        MatOptionModule
                    ],
                    exports: [
                        ReportsComponent,
                        ReportDetailsComponent
                    ],
                    providers: [DatePipe]
                }]
        }] });

/*
 * Public API Surface of reports
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ReportDetailsComponent, ReportsComponent, ReportsModule, ReportsService, sharedGridLayout };
//# sourceMappingURL=reports-hyper74.js.map
